# Segna Python Client Library

The Segna Python Client Library allows users of the [Segna platform](https://platform.segna.io/) to run pipelines from their Python code. 

## Installation

You can install the Segna Python Client Library from [PyPI](https://pypi.org/project/segna/):

    python -m pip install segna

## How to use

Please refer to the [Segna documentation](https://docs.segna.io).